@@ -6,8 +6,12 @@ import json
 import sys
 
 from pyradios import RadioBrowser
+from rich.console import Console
+from rich.table import Table
 from zenlog import log
 
+console = Console()
+
 
 class Handler:
     """
@@ -33,18 +37,32 @@ class Handler:
         # when no response from the API
         if not self.response:
             log.error("No stations found by the name")
-            sys.exit(1)
+            sys.exit(0)  # considering it as not an error
 
         # when multiple results found
         if len(self.response) > 1:
-            log.warn("{} stations found by the name".format(len(self.response)))
+            table = Table(show_header=True, header_style="bold magenta")
+            table.add_column("Station", justify="left")
+            table.add_column("Country", justify="center")
+            table.add_column("UUID", justify="center")
+
+            log.warn(
+                "{} stations found by the name, select one and run with UUID instead".format(
+                    len(self.response)
+                )
+            )
 
             for station in self.response:
-                data = {}
-                data["name"] = station["name"]
-                data["uuid"] = station["stationuuid"]
-                data["country"] = station["country"]
-                log.info(json.dumps(data, indent=3))
+                # data = {}
+                # data["name"] = station["name"]
+                # data["uuid"] = station["stationuuid"]
+                # data["country"] = station["country"]
+                # log.info(json.dumps(data, indent=3))
+                table.add_row(
+                    station["name"], station["countrycode"], station["stationuuid"]
+                )
+
+            console.print(table)
             sys.exit(1)
 
         # when exactly one response found
@@ -52,6 +70,7 @@ class Handler:
             log.info("Station found: {}".format(self.response[0]["name"]))
             log.debug(json.dumps(self.response[0], indent=3))
             self.target_station = self.response[0]
+            # register a valid click to increase its popularity
             self.API.click_counter(self.target_station["stationuuid"])
 
     def play_by_station_name(self, _name=None):
@@ -62,23 +81,8 @@ class Handler:
 
     def play_by_station_uuid(self, _uuid):
         """search and play station by its stationuuid"""
+        self.response = self.API.station_by_uuid(_uuid)
+        self.station_validator()
 
-        # Pyradios by default don't let you search by uuid
-        # a trick is to call click_counter(uuid) directly to get the station info
-        is_ok = "false"
-        try:
-            self.target_station = self.API.click_counter(_uuid)
-            log.debug(json.dumps(self.target_station, indent=3))
-            is_ok = self.target_station["ok"]
-        except Exception:
-            log.error("Could not find the station by the UUID")
-            sys.exit(0)
-
-        log.info("Station found: {}".format(self.target_station["name"]))
-        temp = self.API.search(name=self.target_station["name"], name_exact=True)
-        log.debug(json.dumps(temp, indent=3))
-
-        # register a valid click against the current response
-        if is_ok == "false":
-            res = self.API.click_counter(self.target_station["stationuuid"])
-            log.debug(json.dumps(res, indent=3))
+    def discover_by_country(self, country_code):
+        pass
